@@ -10,6 +10,7 @@ mod gather_elements;
 mod gather_nd;
 mod pad;
 pub mod permute_axes;
+mod range;
 mod reshape;
 mod rm_dims;
 mod scatter_elements;
@@ -34,6 +35,7 @@ pub use gather_elements::GatherElements;
 pub use gather_nd::GatherNd;
 pub use pad::{Pad, PadMode};
 pub use permute_axes::PermuteAxes;
+pub use range::Range;
 pub use reshape::Reshape;
 pub use rm_dims::RmDims;
 pub use scatter_elements::ScatterElements;
